#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MSEVEN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MSEVEN_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mseven.hpp>

#endif
